{% load flot_tags %}
<html>
    <head>
        <script type="text/javascript" src='static/js/jquery.js'></script>
        <script type="text/javascript" src='static/js/jquery.flot.js'></script>
    </head>
    <body>
        <h1>pyFlot examples</h1>
        <!-- Graphs ploted accessing the graph object -->
        <div id="graph1" style="width:300px;height:200px;"></div>
        <script type='text/javascript'>
            $.plot($("#graph1"), {{ graph1.json_data|safe }}, {{ graph1.options|safe }});
        </script>
        <!-- graphs plotted with template tag -->
        <hr/>
        {% plot graph1 style="width:900px;height:200px" class="myclass" %} 
        <hr/>
        {% plot graph2 style="width:900px;height:200px" id="k1" %} 
        <hr/>
        {% plot sin_graph style="width:900px;height:200px" %}
        <hr/>
        {% plot last_series style="width:900px;height:200px" %}
        <hr/>
        {% plot all_series_graph style="width:900px;height:200px" %}
        <hr/>
        {% plot inline_series style="width:900px;height:200px" %}

        {% plot inline_series style="width:900px;height:200px" %}
         
    </body>
</html>
